# TrustUtil

TrustUtil is a toolbox that facilitates the daily work of the Trusfort machine learning algorithm team

EasyTrust is a package related to the score card, mainly with functions：
1 Discretization of continuous features, currently supported strategies are equal frequency, equal width，KS，chimerge，entropy,gini,iv
2 Feature WOE encoding
3 Export credit score card directly
 